@@ -97,6 +97,8 @@ _SEQDB = {
     '< CSI R'            : 'DSR-CPR(cursor position report) response',
     '< CSI 0n'           : 'DSR-OS(operating status report) response: "good status"',
     '< CSI 3n'           : 'DSR-OS(operating status report) response: "it has a malfunction"',
+    '< CSI 1W'           : 'Ambiguous reporting(MinTTY): treat ambiguous width characters as single width',
+    '< CSI 2W'           : 'Ambiguous reporting(MinTTY): treat ambiguous width characters as double width',
     '< CSI ?c'           : 'DA1 Response',
     '< CSI ?1;0c'        : 'DA1 Response: VT100 with no options (could be WizConsole VT100 mode)',
     '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck)',
@@ -273,10 +275,14 @@ _SEQDB = {
     '> ESC ]111<ST>'     : 'OSC 111 / reset VT100 text background color',
     '> ESC ]112<ST>'     : 'OSC 112 / reset cursor color',
     '> ESC ]113<ST>'     : 'OSC 111 / reset VT100 text background color',
+    '> ESC ]701<ST>'     : 'OSC 701 / manipulate locale (MinTTY)',
     '> ESC ]5379<ST>'    : 'OSC 5379 / exec command or set (mlterm)',
     '> ESC ]5380<ST>'    : 'OSC 5380 / get pty (mlterm)',
     '> ESC ]5381<ST>'    : 'OSC 5381 / get GUI menu (mlterm)',
     '> ESC ]5383<ST>'    : 'OSC 5383 / set & save (mlterm)',
+    '> ESC ]7770<ST>'    : 'OSC 7770 / manipulate font size (MinTTY)',
+    '> ESC ]7770;?<ST>'  : 'OSC 7770 / query font size (MinTTY)',
+    '> ESC ]7771<ST>'    : 'OSC 7771 / font coverage (MinTTY)',
     '> ESC ]8900<ST>'    : 'OSC 8890 - GWREPT / glyph width report (yaft)',
     '> ESC ^<ST>'        : 'PM / private message',
     '> ESC _<ST>'        : 'APC / application program command',
@@ -487,6 +493,10 @@ _SEQDB = {
     '> CSI ?7727h'       : 'DECSET 7727 / application escape keycode mode (MinTTY/TeraTerm/RLogin/mlterm/tanasinn)',
     '> CSI ?7728h'       : 'DECSET 7728 / treat ^\ as normal escape keycode (MinTTY)',
     '> CSI ?7766h'       : 'DECSET 7766 / show scroll bar (MinTTY)',
+    '> CSI ?7783h'       : 'DECSET 7783 / enable shortcut override mode (MinTTY)',
+    '> CSI ?7786h'       : 'DECSET 7786 / enable mousewheel reporting (cursor emulation) mode (MinTTY)',
+    '> CSI ?7787h'       : 'DECSET 7787 / enable application mousewheel reporting mode (MinTTY)',
+    '> CSI ?7700h'       : 'DECSET 7700 / enable ambiguous reporting (MinTTY)',
     '> CSI i'            : 'MC',
     '> CSI ?i'           : 'MC - DEC Specific',
     '> CSI l'            : 'RM',
@@ -534,6 +544,10 @@ _SEQDB = {
     '> CSI ?7727l'       : 'DECRST 7727 / normal escape keycode mode (MinTTY)',
     '> CSI ?7728l'       : 'DECRST 7728 / treat ^[ as normal escape keycode (MinTTY)',
     '> CSI ?7766l'       : 'DECRST 7766 / hide scroll bar (MinTTY)',
+    '> CSI ?7783l'       : 'DECSET 7783 / disable shortcut override mode (MinTTY)',
+    '> CSI ?7786l'       : 'DECSET 7786 / disable mousewheel reporting (cursor emulation) mode (MinTTY)',
+    '> CSI ?7787l'       : 'DECSET 7786 / disable application mousewheel reporting mode (MinTTY)',
+    '> CSI ?7700l'       : 'DECSET 7700 / disable ambiguous reporting (MinTTY)',
     '> CSI m'            : 'SGR / select graphics rendition',
     '> CSI 0m'           : 'SGR 0 / reset',
     '> CSI 00m'          : 'SGR 0 / reset',
